==> jaguar_query-0.0.23.tar.gz: lib/src/core/expression/in_between.dart <==
part of query;

/// An in-between conditional expression
class InBetween<ValType> extends Expression {
  /// The field/column of the condition
  final Col<ValType> field;

  /// The low value of the in-between condition
  final ValType low;

  /// The high value of the in-between condition
  final ValType high;

  const InBetween(this.field, this.low, this.high);

  /// Always returns 1 because in-between is not a composite expression
  int get length => 1;

  /// Creates a 'logical and' expression of this expression and the [other]
  @checked
  AndExpression and(Expression exp) {
    AndExpression ret = new AndExpression();
    return ret.and(this).and(exp);
  }

  /// Creates a 'logical or' expression of this expression and the [other]
  @checked
  OrExpression or(Expression exp) {
    OrExpression ret = new OrExpression();
    return ret.or(this).or(exp);
  }

  String toSql() => '(${field.toSql()} BETWEEN $low AND $high)';
}

/// An in-between conditional expression
class InBetweenCol<ValType> extends Expression {
  /// The field/column of the condition
  final Col<ValType> field;

  /// The low value of the in-between condition
  final Col<ValType> low;

  /// The high value of the in-between condition
  final Col<ValType> high;

  const InBetweenCol(this.field, this.low, this.high);

  /// Always returns 1 because in-between is not a composite expression
  int get length => 1;

  /// Creates a 'logical and' expression of this expression and the [other]
  @checked
  AndExpression and(Expression exp) {
    AndExpression ret = new AndExpression();
    return ret.and(this).and(exp);
  }

  /// Creates a 'logical or' expression of this expression and the [other]
  @checked
  OrExpression or(Expression exp) {
    OrExpression ret = new OrExpression();
    return ret.or(this).or(exp);
  }

  String toSql() =>
      '(${field.toSql()} BETWEEN ${low.toSql()} AND ${high.toSql()})';
}

==> jaguar_query-0.1.6.tar.gz: lib/src/core/expression/in_between.dart <==
part of query;

/// An in-between conditional expression
class InBetween<ValType> extends Expression {
  /// The field/column of the condition
  final Col<ValType> field;

  /// The low value of the in-between condition
  final ValType low;

  /// The high value of the in-between condition
  final ValType high;

  const InBetween(this.field, this.low, this.high);

  /// Always returns 1 because in-between is not a composite expression
  int get length => 1;

  /// Creates a 'logical and' expression of this expression and the [other]
  @checked
  And and(Expression exp) {
    And ret = new And();
    return ret.and(this).and(exp);
  }

  /// Creates a 'logical or' expression of this expression and the [other]
  @checked
  Or or(Expression exp) {
    Or ret = new Or();
    return ret.or(this).or(exp);
  }

  String toSql() => '(${field.toSql()} BETWEEN $low AND $high)';
}

/// An in-between conditional expression
class InBetweenCol<ValType> extends Expression {
  /// The field/column of the condition
  final Col<ValType> field;

  /// The low value of the in-between condition
  final Col<ValType> low;

  /// The high value of the in-between condition
  final Col<ValType> high;

  const InBetweenCol(this.field, this.low, this.high);

  /// Always returns 1 because in-between is not a composite expression
  int get length => 1;

  /// Creates a 'logical and' expression of this expression and the [other]
  @checked
  And and(Expression exp) {
    And ret = new And();
    return ret.and(this).and(exp);
  }

  /// Creates a 'logical or' expression of this expression and the [other]
  @checked
  Or or(Expression exp) {
    Or ret = new Or();
    return ret.or(this).or(exp);
  }

  String toSql() =>
      '(${field.toSql()} BETWEEN ${low.toSql()} AND ${high.toSql()})';
}
